ONOS-2851 - Web UI - create archetype for table view based app.
- added uitab overlay archetype.
- renamed stuff so ui apps can coexist.
- WIP ... custom view source needs to be pared down.

Change-Id: I196e10d69ddc231eb0bc9cc5923f29872035b4fd
diff --git a/tools/package/archetypes/ui/src/main/resources/archetype-resources/src/main/java/AppUiComponent.java b/tools/package/archetypes/ui/src/main/resources/archetype-resources/src/main/java/AppUiComponent.java
index f40bcb5..93003a1 100644
--- a/tools/package/archetypes/ui/src/main/resources/archetype-resources/src/main/java/AppUiComponent.java
+++ b/tools/package/archetypes/ui/src/main/resources/archetype-resources/src/main/java/AppUiComponent.java
@@ -34,7 +34,7 @@
 import java.util.List;
 
 /**
  * Skeletal ONOS UI application component.
  */
 @Component(immediate = true)
 public class AppUiComponent {
@@ -46,7 +46,7 @@
 
     // List of application views
     private final List<UiView> uiViews = ImmutableList.of(
-            new UiView(UiView.Category.OTHER, "sample", "Sample")
+            new UiView(UiView.Category.OTHER, "sampleCustom", "Sample Custom")
     );
 
     // Factory for UI message handlers
@@ -34,7 +34,7 @@
 
 /**
- * Skeletal ONOS UI application component.
+ * Skeletal ONOS UI Custom-View application component.
  */
 @Component(immediate = true)